## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----gaawr2_incl, echo=FALSE, results='asis'----------------------------------
htmltools::tags$iframe(
  src = "https://jinghuazhao.github.io/R/vignettes/gaawr2.html",
  width = "100%",
  style = "height:100vh; border:none;"
)

