---
title: " "
output:
  bookdown::html_document2:
    toc: true
    toc_float: true
    number_sections: true
    self_contained: false
pkgdown:
  as_is: true
vignette: >
  %\VignetteIndexEntry{Web facilities}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

```{r gaawr2_incl, echo=FALSE, results='asis'}
htmltools::tags$iframe(
  src = "https://jinghuazhao.github.io/R/vignettes/web.html",
  width = "100%",
  style = "height:100vh; border:none;"
)
```
